@@ -476,6 +476,11 @@ public class BlogViewPageBean
 
     public String getJavaScriptForRedirect()
     {
+        if (log.isDebugEnabled())
+        {
+            log.debug("getJavaScriptForRedirect()");
+        }
+
         ExternalContext exContext = FacesContext.getCurrentInstance()
                 .getExternalContext();
         return "<script type=\"text/javascript\">"
@@ -506,6 +511,6 @@ public class BlogViewPageBean
                 + "\n" + "                    }" + "\n" + "                }"
                 + "\n" + "            }" + "\n" + "        }" + "\n"
                 + "        " + exContext.encodeNamespace("redirect") + "();"
-                + "\n" + "-->" + "\n" + "</script>" + "\n";
+                + "\n" + "//-->" + "\n" + "</script>" + "\n";
     }
 }
